==> trilinos-15.0.0-3-x86_64.pkg.tar.zst: usr/lib/cmake/NOX/NOXTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "NOX::nox" for configuration "RELEASE"
set_property(TARGET NOX::nox APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::nox PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libnox.so.15.0"
  IMPORTED_SONAME_RELEASE "libnox.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::nox )
list(APPEND _cmake_import_check_files_for_NOX::nox "${_IMPORT_PREFIX}/lib/libnox.so.15.0" )

# Import target "NOX::noxlapack" for configuration "RELEASE"
set_property(TARGET NOX::noxlapack APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::noxlapack PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libnoxlapack.so.15.0"
  IMPORTED_SONAME_RELEASE "libnoxlapack.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::noxlapack )
list(APPEND _cmake_import_check_files_for_NOX::noxlapack "${_IMPORT_PREFIX}/lib/libnoxlapack.so.15.0" )

# Import target "NOX::noxepetra" for configuration "RELEASE"
set_property(TARGET NOX::noxepetra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::noxepetra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libnoxepetra.so.15.0"
  IMPORTED_SONAME_RELEASE "libnoxepetra.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::noxepetra )
list(APPEND _cmake_import_check_files_for_NOX::noxepetra "${_IMPORT_PREFIX}/lib/libnoxepetra.so.15.0" )

# Import target "NOX::loca" for configuration "RELEASE"
set_property(TARGET NOX::loca APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::loca PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libloca.so.15.0"
  IMPORTED_SONAME_RELEASE "libloca.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::loca )
list(APPEND _cmake_import_check_files_for_NOX::loca "${_IMPORT_PREFIX}/lib/libloca.so.15.0" )

# Import target "NOX::localapack" for configuration "RELEASE"
set_property(TARGET NOX::localapack APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::localapack PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblocalapack.so.15.0"
  IMPORTED_SONAME_RELEASE "liblocalapack.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::localapack )
list(APPEND _cmake_import_check_files_for_NOX::localapack "${_IMPORT_PREFIX}/lib/liblocalapack.so.15.0" )

# Import target "NOX::locaepetra" for configuration "RELEASE"
set_property(TARGET NOX::locaepetra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::locaepetra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblocaepetra.so.15.0"
  IMPORTED_SONAME_RELEASE "liblocaepetra.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::locaepetra )
list(APPEND _cmake_import_check_files_for_NOX::locaepetra "${_IMPORT_PREFIX}/lib/liblocaepetra.so.15.0" )

# Import target "NOX::locathyra" for configuration "RELEASE"
set_property(TARGET NOX::locathyra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::locathyra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblocathyra.so.15.0"
  IMPORTED_SONAME_RELEASE "liblocathyra.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::locathyra )
list(APPEND _cmake_import_check_files_for_NOX::locathyra "${_IMPORT_PREFIX}/lib/liblocathyra.so.15.0" )

# Import target "NOX::locatpetra" for configuration "RELEASE"
set_property(TARGET NOX::locatpetra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::locatpetra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblocatpetra.so.15.0"
  IMPORTED_SONAME_RELEASE "liblocatpetra.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::locatpetra )
list(APPEND _cmake_import_check_files_for_NOX::locatpetra "${_IMPORT_PREFIX}/lib/liblocatpetra.so.15.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> trilinos-15.1.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/NOX/NOXTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "NOX::nox" for configuration "RELEASE"
set_property(TARGET NOX::nox APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::nox PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libnox.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libnox.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::nox )
list(APPEND _cmake_import_check_files_for_NOX::nox "${_IMPORT_PREFIX}/lib/libnox.so.15.1.1" )

# Import target "NOX::noxlapack" for configuration "RELEASE"
set_property(TARGET NOX::noxlapack APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::noxlapack PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libnoxlapack.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libnoxlapack.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::noxlapack )
list(APPEND _cmake_import_check_files_for_NOX::noxlapack "${_IMPORT_PREFIX}/lib/libnoxlapack.so.15.1.1" )

# Import target "NOX::noxepetra" for configuration "RELEASE"
set_property(TARGET NOX::noxepetra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::noxepetra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libnoxepetra.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libnoxepetra.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::noxepetra )
list(APPEND _cmake_import_check_files_for_NOX::noxepetra "${_IMPORT_PREFIX}/lib/libnoxepetra.so.15.1.1" )

# Import target "NOX::loca" for configuration "RELEASE"
set_property(TARGET NOX::loca APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::loca PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libloca.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libloca.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::loca )
list(APPEND _cmake_import_check_files_for_NOX::loca "${_IMPORT_PREFIX}/lib/libloca.so.15.1.1" )

# Import target "NOX::localapack" for configuration "RELEASE"
set_property(TARGET NOX::localapack APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::localapack PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblocalapack.so.15.1.1"
  IMPORTED_SONAME_RELEASE "liblocalapack.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::localapack )
list(APPEND _cmake_import_check_files_for_NOX::localapack "${_IMPORT_PREFIX}/lib/liblocalapack.so.15.1.1" )

# Import target "NOX::locaepetra" for configuration "RELEASE"
set_property(TARGET NOX::locaepetra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::locaepetra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblocaepetra.so.15.1.1"
  IMPORTED_SONAME_RELEASE "liblocaepetra.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::locaepetra )
list(APPEND _cmake_import_check_files_for_NOX::locaepetra "${_IMPORT_PREFIX}/lib/liblocaepetra.so.15.1.1" )

# Import target "NOX::locathyra" for configuration "RELEASE"
set_property(TARGET NOX::locathyra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::locathyra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblocathyra.so.15.1.1"
  IMPORTED_SONAME_RELEASE "liblocathyra.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::locathyra )
list(APPEND _cmake_import_check_files_for_NOX::locathyra "${_IMPORT_PREFIX}/lib/liblocathyra.so.15.1.1" )

# Import target "NOX::locatpetra" for configuration "RELEASE"
set_property(TARGET NOX::locatpetra APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(NOX::locatpetra PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/liblocatpetra.so.15.1.1"
  IMPORTED_SONAME_RELEASE "liblocatpetra.so.15"
  )

list(APPEND _cmake_import_check_targets NOX::locatpetra )
list(APPEND _cmake_import_check_files_for_NOX::locatpetra "${_IMPORT_PREFIX}/lib/liblocatpetra.so.15.1.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
